@@ -12,7 +12,7 @@ c = osl.get_client(CLOUD, "placement", osl.schema("placement.yaml"))
 @pytest.fixture
 def rp():
     orig_rp = {"name": TEST_RP}
-    c.resource_providers.create_resource_provider(body=orig_rp)
+    c.resource_providers.create_resource_provider(resource_provider=orig_rp)
     rp = c.resource_providers.list_resource_providers(
         name=orig_rp["name"]
     )["resource_providers"][0]
